@@ -3,10 +3,10 @@
 import typing as t
 
 from databases import Database
-from muffin.plugin import BasePlugin
+from muffin.plugins import BasePlugin
 
 
-__version__ = "0.2.5"
+__version__ = "0.3.1"
 __project__ = "muffin-databases"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -18,10 +18,17 @@ class Plugin(BasePlugin):
 
     name = 'databases'
     defaults: t.Dict = {
-        'url': 'sqlite:///:memory:',
         'params': {},
+        'url': 'sqlite:///:memory:',
     }
 
+    def __getattr__(self, name) -> t.Any:
+        """Proxy attributes to self database."""
+        if not self.installed:
+            raise AttributeError(name)
+
+        return getattr(self.__database__, name)
+
     def setup(self, *args, **options):
         """Initialize a database."""
         super(Plugin, self).setup(*args, **options)
@@ -35,10 +42,3 @@ class Plugin(BasePlugin):
     async def shutdown(self):
         """Disconnect the database."""
         await self.__database__.disconnect()
-
-    def __getattr__(self, name) -> t.Any:
-        """Proxy attributes to self database."""
-        if not self.installed:
-            raise AttributeError(name)
-
-        return getattr(self.__database__, name)
